import requests

from avishan.models import Country
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = 'Imports countries from https://restcountries.eu/rest/v2/all'

    def handle(self, *args, **kwargs):

        response = requests.get(url='https://restcountries.eu/rest/v2/all').json()

        for item in response:
            if item['numericCode'] is None:
                print(f'{item["name"]} skipped')
                continue
            try:
                country = Country.objects.get(numeric_code=item['numericCode'])
                country.update(
                    name=item['name'],
                    alpha_2_code=item['alpha2Code'],
                    alpha_3_code=item['alpha3Code'],
                    region=item['region'],
                    native_name=item['nativeName'],
                    flag=item['flag']
                )
                print(f'update {country.name}')
            except Country.DoesNotExist:
                country = Country.create(
                    numeric_code=item['numericCode'],
                    name=item['name'],
                    alpha_2_code=item['alpha2Code'],
                    alpha_3_code=item['alpha3Code'],
                    region=item['region'],
                    native_name=item['nativeName'],
                    flag=item['flag']
                )
                print(f'create {country.name}')



# Generated by Django 2.2.6 on 2020-01-18 19:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('avishan', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='TranslatableChar',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('en', models.CharField(blank=True, default=None, max_length=255, null=True)),
                ('fa', models.CharField(blank=True, default=None, max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = 'Creates avishan config file'

    def handle(self, *args, **kwargs):
        from avishan.configure import AvishanConfigure

        AvishanConfigure.command_line_checkup(self)



from django.urls import path

from avishan.views.class_based import AvishanModelApiView, Redoc
from avishan.configure import get_avishan_config

urlpatterns = [
    path(f'{get_avishan_config().AVISHAN_URLS_START}'
         f'/redoc',
         Redoc.as_view()),
    path(f'{get_avishan_config().AVISHAN_URLS_START}'
         f'/<str:model_plural_name>',
         AvishanModelApiView.as_view()),
    path(f'{get_avishan_config().AVISHAN_URLS_START}'
         f'/<str:model_plural_name>/<int:model_item_id>',
         AvishanModelApiView.as_view()),
    path(f'{get_avishan_config().AVISHAN_URLS_START}'
         f'/<str:model_plural_name>/<str:model_function_name>',
         AvishanModelApiView.as_view()),
    path(
        f'{get_avishan_config().AVISHAN_URLS_START}'
        f'/<str:model_plural_name>/<int:model_item_id>/<str:model_function_name>',
        AvishanModelApiView.as_view()
    )
]



# Generated by Django 3.0.3 on 2020-03-31 20:41

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('avishan', '0008_auto_20200312_1444'),
    ]

    operations = [
        migrations.CreateModel(
            name='Activity',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('request_track', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='avishan.RequestTrack')),
                ('user_user_group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='avishan.UserUserGroup')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.DeleteModel(
            name='RequestTrackMessage',
        ),
    ]



from django import template
from django.db import models

from avishan.models import AvishanModel

register = template.Library()


@register.filter
def translator(value: str) -> str:
    data = {
        'phone': 'شماره همراه',
        'email': 'ایمیل',
    }
    try:
        return data[value.lower()]
    except KeyError:
        return value


@register.filter
def leading_zeros(value, desired_digits):
    """
    Given an integer, returns a string representation, padded with [desired_digits] zeros.
    """
    num_zeros = int(desired_digits) - len(str(value))
    padded_value = []
    while num_zeros >= 1:
        padded_value.append("0")
        num_zeros = num_zeros - 1
    padded_value.append(str(value))
    return "".join(padded_value)



# Generated by Django 3.0.5 on 2020-05-26 17:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('avishan', '0010_auto_20200401_1452'),
    ]

    operations = [
        migrations.AddField(
            model_name='requesttrack',
            name='request_data_size',
            field=models.BigIntegerField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='requesttrack',
            name='response_data_size',
            field=models.BigIntegerField(blank=True, default=None, null=True),
        ),
    ]



# Generated by Django 3.0.3 on 2020-02-19 04:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('avishan', '0005_baseuser_language'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='email',
            name='is_verified',
        ),
        migrations.RemoveField(
            model_name='phone',
            name='is_verified',
        ),
        migrations.AddField(
            model_name='email',
            name='date_verified',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='phone',
            name='date_verified',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
    ]
